@@ -527,7 +527,9 @@ impl Channel {
             return Err(Error::InvalidChannelState(self.status.state()));
         }
 
-        match self.frames.next_expected_reply(self.id) {
+        match self.frames.find_expected_reply(self.id, |reply| {
+            matches!(&reply.0, Reply::ConnectionOpenOk(..))
+        }) {
             Some(Reply::ConnectionOpenOk(resolver, connection)) => {
                 let res = self.on_connection_open_ok_received(method, connection);
                 resolver.swear(res.clone());
@@ -618,7 +620,9 @@ impl Channel {
             return Err(Error::InvalidChannelState(self.status.state()));
         }
 
-        match self.frames.next_expected_reply(self.id) {
+        match self.frames.find_expected_reply(self.id, |reply| {
+            matches!(&reply.0, Reply::ConnectionCloseOk(..))
+        }) {
             Some(Reply::ConnectionCloseOk(resolver)) => {
                 let res = self.on_connection_close_ok_received();
                 resolver.swear(res.clone());
@@ -727,7 +731,9 @@ impl Channel {
             return Err(Error::InvalidChannelState(self.status.state()));
         }
 
-        match self.frames.next_expected_reply(self.id){
+        match self.frames.find_expected_reply(self.id, |reply| {
+            matches!(&reply.0, Reply::ConnectionUpdateSecretOk(..))
+        }) {
             Some(Reply::ConnectionUpdateSecretOk(resolver)) => {
                 let res = Ok(());
                 resolver.swear(res.clone());
@@ -773,7 +779,9 @@ impl Channel {
             return Err(Error::InvalidChannelState(self.status.state()));
         }
 
-        match self.frames.next_expected_reply(self.id) {
+        match self.frames.find_expected_reply(self.id, |reply| {
+            matches!(&reply.0, Reply::ChannelOpenOk(..))
+        }) {
             Some(Reply::ChannelOpenOk(resolver, channel)) => {
                 self.on_channel_open_ok_received(method, resolver, channel)
             }
@@ -850,7 +858,9 @@ impl Channel {
             return Err(Error::InvalidChannelState(self.status.state()));
         }
 
-        match self.frames.next_expected_reply(self.id) {
+        match self.frames.find_expected_reply(self.id, |reply| {
+            matches!(&reply.0, Reply::ChannelFlowOk(..))
+        }) {
             Some(Reply::ChannelFlowOk(resolver)) => {
                 self.on_channel_flow_ok_received(method, resolver)
             }
@@ -1001,7 +1011,9 @@ impl Channel {
             return Err(Error::InvalidChannelState(self.status.state()));
         }
 
-        match self.frames.next_expected_reply(self.id) {
+        match self.frames.find_expected_reply(self.id, |reply| {
+            matches!(&reply.0, Reply::AccessRequestOk(..))
+        }) {
             Some(Reply::AccessRequestOk(resolver)) => {
                 let res = self.on_access_request_ok_received(method);
                 resolver.swear(res.clone());
@@ -1088,7 +1100,9 @@ impl Channel {
             return Err(Error::InvalidChannelState(self.status.state()));
         }
 
-        match self.frames.next_expected_reply(self.id) {
+        match self.frames.find_expected_reply(self.id, |reply| {
+            matches!(&reply.0, Reply::ExchangeDeclareOk(..))
+        }) {
             Some(Reply::ExchangeDeclareOk(
                 resolver,
                 exchange,
@@ -1157,7 +1171,9 @@ impl Channel {
             return Err(Error::InvalidChannelState(self.status.state()));
         }
 
-        match self.frames.next_expected_reply(self.id) {
+        match self.frames.find_expected_reply(self.id, |reply| {
+            matches!(&reply.0, Reply::ExchangeDeleteOk(..))
+        }) {
             Some(Reply::ExchangeDeleteOk(resolver, exchange)) => {
                 let res = self.on_exchange_delete_ok_received(exchange);
                 resolver.swear(res.clone());
@@ -1233,7 +1249,9 @@ impl Channel {
             return Err(Error::InvalidChannelState(self.status.state()));
         }
 
-        match self.frames.next_expected_reply(self.id) {
+        match self.frames.find_expected_reply(self.id, |reply| {
+            matches!(&reply.0, Reply::ExchangeBindOk(..))
+        }) {
             Some(Reply::ExchangeBindOk(
                 resolver,
                 destination,
@@ -1320,7 +1338,9 @@ impl Channel {
             return Err(Error::InvalidChannelState(self.status.state()));
         }
 
-        match self.frames.next_expected_reply(self.id) {
+        match self.frames.find_expected_reply(self.id, |reply| {
+            matches!(&reply.0, Reply::ExchangeUnbindOk(..))
+        }) {
             Some(Reply::ExchangeUnbindOk(
                 resolver,
                 destination,
@@ -1412,7 +1432,9 @@ impl Channel {
             return Err(Error::InvalidChannelState(self.status.state()));
         }
 
-        match self.frames.next_expected_reply(self.id) {
+        match self.frames.find_expected_reply(self.id, |reply| {
+            matches!(&reply.0, Reply::QueueDeclareOk(..))
+        }) {
             Some(Reply::QueueDeclareOk(resolver, options, creation_arguments)) => {
                 self.on_queue_declare_ok_received(method, resolver, options, creation_arguments)
             }
@@ -1484,7 +1506,10 @@ impl Channel {
             return Err(Error::InvalidChannelState(self.status.state()));
         }
 
-        match self.frames.next_expected_reply(self.id) {
+        match self
+            .frames
+            .find_expected_reply(self.id, |reply| matches!(&reply.0, Reply::QueueBindOk(..)))
+        {
             Some(Reply::QueueBindOk(
                 resolver,
                 queue,
@@ -1549,7 +1574,10 @@ impl Channel {
             return Err(Error::InvalidChannelState(self.status.state()));
         }
 
-        match self.frames.next_expected_reply(self.id) {
+        match self
+            .frames
+            .find_expected_reply(self.id, |reply| matches!(&reply.0, Reply::QueuePurgeOk(..)))
+        {
             Some(Reply::QueuePurgeOk(resolver)) => {
                 self.on_queue_purge_ok_received(method, resolver)
             }
@@ -1616,7 +1644,9 @@ impl Channel {
             return Err(Error::InvalidChannelState(self.status.state()));
         }
 
-        match self.frames.next_expected_reply(self.id) {
+        match self.frames.find_expected_reply(self.id, |reply| {
+            matches!(&reply.0, Reply::QueueDeleteOk(..))
+        }) {
             Some(Reply::QueueDeleteOk(resolver, queue)) => {
                 self.on_queue_delete_ok_received(method, resolver, queue)
             }
@@ -1681,7 +1711,9 @@ impl Channel {
             return Err(Error::InvalidChannelState(self.status.state()));
         }
 
-        match self.frames.next_expected_reply(self.id) {
+        match self.frames.find_expected_reply(self.id, |reply| {
+            matches!(&reply.0, Reply::QueueUnbindOk(..))
+        }) {
             Some(Reply::QueueUnbindOk(
                 resolver,
                 queue,
@@ -1744,7 +1776,10 @@ impl Channel {
             return Err(Error::InvalidChannelState(self.status.state()));
         }
 
-        match self.frames.next_expected_reply(self.id) {
+        match self
+            .frames
+            .find_expected_reply(self.id, |reply| matches!(&reply.0, Reply::BasicQosOk(..)))
+        {
             Some(Reply::BasicQosOk(resolver)) => {
                 let res = Ok(());
                 resolver.swear(res.clone());
@@ -1832,7 +1867,9 @@ impl Channel {
             return Err(Error::InvalidChannelState(self.status.state()));
         }
 
-        match self.frames.next_expected_reply(self.id) {
+        match self.frames.find_expected_reply(self.id, |reply| {
+            matches!(&reply.0, Reply::BasicConsumeOk(..))
+        }) {
             Some(Reply::BasicConsumeOk(
                 resolver,
                 channel_closer,
@@ -1931,7 +1968,9 @@ impl Channel {
             return Err(Error::InvalidChannelState(self.status.state()));
         }
 
-        match self.frames.next_expected_reply(self.id) {
+        match self.frames.find_expected_reply(self.id, |reply| {
+            matches!(&reply.0, Reply::BasicCancelOk(..))
+        }) {
             Some(Reply::BasicCancelOk(resolver)) => {
                 let res = self.on_basic_cancel_ok_received(method);
                 resolver.swear(res.clone());
@@ -2038,7 +2077,10 @@ impl Channel {
             return Err(Error::InvalidChannelState(self.status.state()));
         }
 
-        match self.frames.next_expected_reply(self.id) {
+        match self
+            .frames
+            .find_expected_reply(self.id, |reply| matches!(&reply.0, Reply::BasicGetOk(..)))
+        {
             Some(Reply::BasicGetOk(resolver, queue, options)) => {
                 self.on_basic_get_ok_received(method, resolver, queue, options)
             }
@@ -2172,7 +2214,9 @@ impl Channel {
             return Err(Error::InvalidChannelState(self.status.state()));
         }
 
-        match self.frames.next_expected_reply(self.id) {
+        match self.frames.find_expected_reply(self.id, |reply| {
+            matches!(&reply.0, Reply::BasicRecoverOk(..))
+        }) {
             Some(Reply::BasicRecoverOk(resolver)) => {
                 let res = self.on_basic_recover_ok_received();
                 resolver.swear(res.clone());
@@ -2251,7 +2295,10 @@ impl Channel {
             return Err(Error::InvalidChannelState(self.status.state()));
         }
 
-        match self.frames.next_expected_reply(self.id) {
+        match self
+            .frames
+            .find_expected_reply(self.id, |reply| matches!(&reply.0, Reply::TxSelectOk(..)))
+        {
             Some(Reply::TxSelectOk(resolver)) => {
                 let res = Ok(());
                 resolver.swear(res.clone());
@@ -2298,7 +2345,10 @@ impl Channel {
             return Err(Error::InvalidChannelState(self.status.state()));
         }
 
-        match self.frames.next_expected_reply(self.id) {
+        match self
+            .frames
+            .find_expected_reply(self.id, |reply| matches!(&reply.0, Reply::TxCommitOk(..)))
+        {
             Some(Reply::TxCommitOk(resolver)) => {
                 let res = Ok(());
                 resolver.swear(res.clone());
@@ -2347,7 +2397,10 @@ impl Channel {
             return Err(Error::InvalidChannelState(self.status.state()));
         }
 
-        match self.frames.next_expected_reply(self.id) {
+        match self
+            .frames
+            .find_expected_reply(self.id, |reply| matches!(&reply.0, Reply::TxRollbackOk(..)))
+        {
             Some(Reply::TxRollbackOk(resolver)) => {
                 let res = Ok(());
                 resolver.swear(res.clone());
@@ -2397,7 +2450,9 @@ impl Channel {
             return Err(Error::InvalidChannelState(self.status.state()));
         }
 
-        match self.frames.next_expected_reply(self.id) {
+        match self.frames.find_expected_reply(self.id, |reply| {
+            matches!(&reply.0, Reply::ConfirmSelectOk(..))
+        }) {
             Some(Reply::ConfirmSelectOk(resolver)) => {
                 let res = self.on_confirm_select_ok_received();
                 resolver.swear(res.clone());
